@@ -1,9 +1,7 @@
 # _*_ coding: utf-8 _*_
 from zope.interface import implementer
 
-from fhirpath.interfaces import IConnection
-from fhirpath.interfaces import IDialect
-
+from fhirpath.interfaces import IConnection, IDialect
 
 __author__ = "Md Nazrul Islam <email2nazrul@gmail.com>"
 
@@ -27,3 +25,11 @@ class DialectBase(object):
     def pre_compile(self, query):
         """xxx: validation placeholder"""
         pass
+
+    @staticmethod
+    def is_fhir_primitive_type(klass):
+        """ """
+        if klass is bool:
+            return True
+        else:
+            return klass.is_primitive()
