@@ -15,6 +15,7 @@ from typing import (
     cast,
 )
 from urllib.parse import unquote_plus
+from warnings import warn
 
 from multidict import MultiDict, MultiDictProxy
 from zope.interface import implementer
@@ -32,6 +33,7 @@ from fhirpath.fhirspec import (
     FHIRSearchSpecFactory,
     ResourceSearchParameterDefinition,
     SearchParameter,
+    lookup_fhir_resource_spec,
     search_param_prefixes,
 )
 from fhirpath.fql import (
@@ -85,12 +87,18 @@ class SearchContext(object):
 
     definitions: List[ResourceSearchParameterDefinition]
 
-    def __init__(self, engine, resource_type, unrestricted=False, async_result=False):
+    def __init__(self, engine, resource_type, unrestricted=False, async_result=None):
         """ """
         self.engine = engine
         self.resource_types = [resource_type] if resource_type else []
         self.unrestricted = unrestricted
-        self.async_result = async_result
+        self.async_result = self.engine.__class__.is_async()
+        if async_result is not None:
+            warn(
+                "'async_result' is no longer used, as Engine has that info already. "
+                "this parameter will be removed in future release.",
+                category=DeprecationWarning,
+            )
 
         self.definitions = self.get_parameters_definition(self.engine.fhir_release)
 
@@ -450,7 +458,7 @@ class Search(object):
 
         _elements = all_params.popone("_elements", [])
         if len(_elements) > 0:
-            self.result_params["_elements"] = ",".join(_elements)
+            self.result_params["_elements"] = _elements.split(",")
 
         _contained = all_params.popone("_contained", None)
         if _contained:
@@ -467,7 +475,9 @@ class Search(object):
         builder = Q_(self.context.resource_types, self.context.engine)
 
         builder = self.attach_where_terms(builder)
+        builder = self.attach_elements_terms(builder)
         builder = self.attach_sort_terms(builder)
+        builder = self.attach_summary_terms(builder)
         builder = self.attach_limit_terms(builder)
 
         # handle _has predicates
@@ -481,10 +491,7 @@ class Search(object):
 
             builder = builder.where(*terms)
 
-        result: QueryResult = builder(
-            unrestricted=self.context.unrestricted,
-            async_result=self.context.async_result,
-        )
+        result: QueryResult = builder(unrestricted=self.context.unrestricted)
 
         return result
 
@@ -549,10 +556,7 @@ class Search(object):
             builder = builder.where(*terms_container)
             self.attach_limit_terms(builder)
 
-            result: QueryResult = builder(
-                unrestricted=self.context.unrestricted,
-                async_result=self.context.async_result,
-            )
+            result: QueryResult = builder(unrestricted=self.context.unrestricted)
             has_queries.append((ref_param, result))
 
         return has_queries
@@ -629,10 +633,7 @@ class Search(object):
             # FIXME: find a better way to handle the limit
             builder = builder.limit(DEFAULT_RESULT_COUNT)
 
-            result: QueryResult = builder(
-                unrestricted=self.context.unrestricted,
-                async_result=self.context.async_result,
-            )
+            result: QueryResult = builder(unrestricted=self.context.unrestricted)
             include_queries.append(result)
 
         return include_queries
@@ -699,10 +700,7 @@ class Search(object):
             builder = builder.where(*terms)
             self.attach_limit_terms(builder)
 
-            result: QueryResult = builder(
-                unrestricted=self.context.unrestricted,
-                async_result=self.context.async_result,
-            )
+            result: QueryResult = builder(unrestricted=self.context.unrestricted)
             include_queries.append(result)
 
         return include_queries
@@ -1557,6 +1555,90 @@ class Search(object):
                 offset = (current_page - 1) * self.result_params["_count"]
         return builder.limit(self.result_params["_count"], offset)
 
+    def attach_elements_terms(self, builder):
+        """ """
+        if "_elements" not in self.result_params:
+            return builder
+
+        paths = [
+            f"{r}.{el}"
+            for el in self.result_params["_elements"]
+            for r in self.context.resource_types
+        ]
+        mandatories = [
+            f"{r}.{el}" for el in ["id"] for r in self.context.resource_types
+        ]
+        return builder.element(*paths, *mandatories)
+
+    def attach_summary_terms(self, builder):
+        """ """
+        if "_summary" not in self.result_params:
+            return builder
+
+        if self.result_params["_summary"] in ["count", "false"]:
+            return builder
+
+        specs = [
+            lookup_fhir_resource_spec(r, True, FHIR_VERSION.R4)
+            for r in self.context.resource_types
+        ]
+
+        if self.result_params["_summary"] in ("data", "true"):
+
+            summary_elements = [
+                f"{r}.{attr}"
+                for r in self.context.resource_types
+                for attr in ["id", "meta"]
+            ]
+
+            def should_include(attr):
+                if self.result_params["_summary"] == "data":
+                    return (
+                        not attr.path.endswith(".text")
+                        and not attr.is_main_profile_element
+                    )
+                elif self.result_params["_summary"] == "true":
+                    return attr.is_summary
+
+            # filter all summary attributes
+            summary_attributes = [
+                attr for spec in specs for attr in spec.elements if should_include(attr)
+            ]
+
+            def get_attr_paths(attribute):
+                if attribute.path.endswith("[x]"):
+                    for prop in attribute.as_properties():
+                        return [
+                            f"{prop.path.rsplit('.', 1)[0]}.{prop.name}"
+                            for prop in attribute.as_properties()
+                        ]
+                else:
+                    return [attribute.path]
+
+            # append summary attributes' paths to summary_elements
+            summary_elements.extend(
+                [path for attr in summary_attributes for path in get_attr_paths(attr)]
+            )
+
+            return builder.element(*summary_elements)
+
+        if self.result_params["_summary"] == "text":
+            text_elements = [
+                el.path
+                for spec in specs
+                for el in spec.elements
+                if el.n_min is not None and el.n_min > 0
+            ]
+            text_elements.extend(
+                [
+                    f"{r}.{attr}"
+                    for r in self.context.resource_types
+                    for attr in ["text", "id", "meta"]
+                ]
+            )
+
+            return builder.element(*text_elements)
+
     def response(self, result, includes, as_json):
         """ """
         return self.context.engine.wrapped_with_bundle(
@@ -1599,7 +1681,7 @@ class Search(object):
 
         # TODO handle count with _includes
         if self.result_params.get("_summary") == "count":
-            main_result = self.main_query.count()
+            main_result = self.main_query.count_raw()
         else:
             main_result = self.main_query.fetchall()
         assert main_result is not None
@@ -1654,7 +1736,7 @@ class AsyncSearch(Search):
 
         # TODO handle count with _includes
         if self.result_params.get("_summary") == "count":
-            main_result = await self.main_query.count()
+            main_result = await self.main_query.count_raw()
         else:
             main_result = await self.main_query.fetchall()
         assert main_result is not None
@@ -1684,7 +1766,7 @@ def fhir_search(
     """ """
     if TYPE_CHECKING:
         klass: Union[Type[AsyncSearch], Type[Search]]
-    if context.async_result:
+    if context.engine.__class__.is_async():
         klass = AsyncSearch
     else:
         klass = Search
