@@ -2,27 +2,18 @@
 """©FHIR Data Primitive Types
 https://www.hl7.org/fhir/datatypes.html#primitive
 """
-from __future__ import annotations
-
 import base64
 import re
 from collections import deque
-from datetime import date
-from datetime import datetime
-from typing import Deque
-from typing import Optional
-from typing import Text
-from typing import Union
+from datetime import date, datetime
+from typing import Deque, Optional, Text, Union
 
 import isodate
 from zope.interface import implementer
 
 from fhirpath.thirdparty import ImmutableDict
 
-from .interfaces import IFhirPrimitiveType
-from .interfaces import IPrimitiveTypeCollection
-from .interfaces import ITypeSpecifier
-
+from .interfaces import IFhirPrimitiveType, IPrimitiveTypeCollection, ITypeSpecifier
 
 __author__ = "Md Nazrul Islam <email2nazrul@gmail.com>"
 
@@ -87,7 +78,9 @@ class FhirBoolean(FhirPrimitiveType):
         """ """
         res = re.match(self.__regex__, self)
         if not res:
-            raise ValueError("Invalid FHIR boolean value! should true or false")
+            raise ValueError(
+                f"Invalid boolean value: expected true or false, got {self}"
+            )
 
     def to_python(self) -> bool:
         """ """
@@ -326,7 +319,7 @@ class FhirDate(FhirPrimitiveType):
 
 
 class FhirDateTime(FhirPrimitiveType):
-    """	A date, date-time or partial date (e.g. just year or year + month) as used in
+    """A date, date-time or partial date (e.g. just year or year + month) as used in
     human communication. The format is YYYY, YYYY-MM, YYYY-MM-DD or
     YYYY-MM-DDThh:mm:ss+zz:zz, e.g. 2018, 1973-06, 1905-08-23,
     2015-02-07T13:28:17-05:00 or 2017-01-01T00:00:00.000Z.
