@@ -39,7 +39,7 @@ from .storage import FHIR_RESOURCE_CLASS_STORAGE, PATH_INFO_STORAGE
 from .types import PrimitiveDataTypes
 
 if TYPE_CHECKING:
-    from fhir.resources.fhirabstractmodel import FHIRAbstractModel  # noqa: F401
+    from fhir.resources.fhirabstractmodel import FHIRAbstractModel
     from fhir.resources.fhirtypes import (  # noqa: F401
         AbstractBaseType,
         AbstractType,
@@ -54,6 +54,11 @@ __author__ = "Md Nazrul Islam <email2nazrul@gmail.com>"
 LOCAL_TIMEZONE: Optional[datetime.timezone] = None
 
 
+def fallback_callable(*args, **kwargs):
+    """Always return None"""
+    return None
+
+
 def _reraise(tp, value, tb=None):
     if value is None:
         value = tp
@@ -65,7 +70,7 @@ def _reraise(tp, value, tb=None):
 def reraise(klass, msg=None, callback=None, **kw):
     """Reraise custom exception class"""
     if not issubclass(klass, Exception):
-        raise RuntimeError(f"Class ``{klass}`` must be derrived from Exception class.")
+        raise RuntimeError(f"Class ``{klass}`` must be derived from Exception class.")
     t, v, tb = sys.exc_info()
     msg = msg or str(v)
     try:
@@ -234,7 +239,7 @@ def lookup_fhir_class(
 
 
 CONTAINS_PY_PACKAGE: Pattern = re.compile(
-    r"^\${(?P<package_name>[0-9a-z._]+)\}", re.IGNORECASE
+    r"^\${(?P<package_name>[0-9a-z._]+)}", re.IGNORECASE
 )
 
 
@@ -578,12 +583,12 @@ class BundleWrapper:
             if isinstance(resource, dict):
                 resource_id = resource["id"]
                 resource_type = resource["resourceType"]
-            elif isinstance(resource, FHIRAbstractModel):
+            elif getattr(resource.__class__, "get_resource_type", fallback_callable)():
                 resource_id = resource.id
                 resource_type = resource.resource_type
             else:
                 raise NotImplementedError(
-                    f"EngineRowResult must be a dict or FHIRAbstractModel, got: {row}"
+                    f"EngineRowResult must be a dict or FHIRAbstractModel, got: {resource}"
                 )
             # entry = BundleEntry
             entry = dict()
